<template>
    <el-main class="ht-table-panel" ref="tablePanel">
        <div class="toolbar-panel" ref="toolbarPanel">
            <el-row v-if="!justShowSearch" class="ht-quick__search">
                <el-col :span="22" class="search-container__col">
                    <ht-input
                        class="quick-search"
                        v-if="quickSearchConfig && quickSearchConfig.length > 0"
                        v-model.lazy="quickSearchWord"
                        @keyup.enter.native="quickSearch"
                        :placeholder="quickSearchPlaceholder"
                        :autofocus="true"
                        :disabled="loading || showAdvancedSearch"
                        ref="quickSearch"
                        :debounce="2000"
                    >
                        <el-button
                            slot="append"
                            :disabled="loading || showAdvancedSearch"
                            icon="el-icon-search"
                            @click="quickSearch"
                        ></el-button>
                    </ht-input>
                    <el-divider
                        v-if="quickSearchConfig && quickSearchConfig.length > 0"
                        direction="vertical"
                    ></el-divider>
                    <slot name="toolbar"></slot>
                </el-col>
                <el-col :span="2" class="common-tools">
                    <el-tooltip
                        v-if="showCustomColumn"
                        content="自定义列表项"
                        placement="top"
                    >
                        <el-button
                            icon="el-icon-s-tools"
                            size="large"
                            @click="customColumnDialogVisible = true"
                        />
                    </el-tooltip>
                    <el-tooltip v-if="showExport" content="导出数据" placement="top">
                        <el-button icon="el-icon-folder-checked" size="large" />
                    </el-tooltip>
                    <el-button
                        :style="searchBtnStyle"
                        type="text"
                        style="margin-top: 2px"
                        v-if="hasSearchPanel && !justShowSearch"
                        @click="showAdvancedSearch = !showAdvancedSearch"
                        >{{
                            showAdvancedSearch
                                ? showAdvancedSearchText
                                : hideAdvancedSearchText
                        }}</el-button
                    >
                </el-col>
            </el-row>
        </div>
        <el-collapse-transition>
            <div v-show="showAdvancedSearch || justShowSearch" ref="searchPanel">
                <slot name="search"></slot>
            </div>
        </el-collapse-transition>
        <div
            class="htTable-outer"
            :style="{
                height: `${tableMaxHeight}` + 'px',
            }"
        >
            <el-table
                :data="data"
                v-loading="loading"
                ref="htTable"
                stripe
                border
                :show-header="showHeader"
                :max-height="tableMaxHeight - 2"
                :default-querys="defaultQuerys"
                :highlight-current-row="highlightCurrentRow"
                :header-row-class-name="headerRowClassName"
                :row-class-name="rowClassName"
                @row-click="handleRowClick"
                @select="handleTableSelect"
                @select-all="handleTableSelect"
                @sort-change="handleSortChange"
                @filter-change="handleFilterChange"
                @row-dblclick="handleRowDBClick"
                class="ht-table"
                size="mini"
            >
                <el-table-column
                    type="selection"
                    align="center"
                    width="65"
                    v-if="this.selectable"
                    :selectable="filterSelectable"
                />
                <slot></slot>
            </el-table>
        </div>
        <div v-if="!nopagination" class="pagination-panel" ref="paginationPanel">
            <el-row type="flex" :justify="paginationJustify">
                <el-pagination
                    small
                    :disabled="loading"
                    @size-change="handleSizeChange"
                    @current-change="handleCurrentChange"
                    :current-page="pagination.page"
                    :page-sizes="pageSizes"
                    :page-size="pagination.pageSize"
                    :pager-count="pagerCount"
                    :background="$paginationBackground"
                    layout="total, sizes, prev, pager, next, jumper"
                    :total="pagination.total"
                ></el-pagination>
            </el-row>
        </div>
        <el-dialog
            title="自定义列表项"
            :visible.sync="customColumnDialogVisible"
            :before-close="customColumnDialogCancel"
            width="700px"
            :close-on-click-modal="false"
            append-to-body
        >
            <ht-checkbox v-model="currentCustomColumns" :options="customColumns" />
            <span slot="footer" class="dialog-footer">
                <el-button type="primary" size="small" @click="customColumnDialogSure"
                    >确 定</el-button
                >
                <el-button size="small" @click="customColumnDialogCancel"
                    >取 消</el-button
                >
            </span>
        </el-dialog>
    </el-main>
</template>

<script>
import HotentUi from 'bpm_el_ui'
export default {
    name: 'ExtendHtTable',
    props: {
        rowClassName: [String, Function],
    },
    extends: HotentUi.HtTable,
}
</script>
